REORG: thread/sched: move the thread_info flags to the thread_ctx

The TI_FL_STUCK flag is manipulated by the watchdog and scheduler
and describes the apparent life/death of a thread so it changes
all the time and it makes sense to move it to the thread's context
for an active thread.
diff --git a/src/wdt.c b/src/wdt.c
index b789fbe..b9d6ca7 100644
--- a/src/wdt.c
+++ b/src/wdt.c
@@ -92,13 +92,13 @@
 		 * certain that we're not witnessing an exceptional spike of
 		 * CPU usage due to a configuration issue (like running tens
 		 * of thousands of tasks in a single loop), we'll check if the
 		 * scheduler is still alive by setting the TI_FL_STUCK flag
 		 * that the scheduler clears when switching to the next task.
 		 * If it's already set, then it's our second call with no
 		 * progress and the thread is dead.
 		 */
-		if (!(ha_thread_info[thr].flags & TI_FL_STUCK)) {
-			_HA_ATOMIC_OR(&ha_thread_info[thr].flags, TI_FL_STUCK);
+		if (!(ha_thread_ctx[thr].flags & TH_FL_STUCK)) {
+			_HA_ATOMIC_OR(&ha_thread_ctx[thr].flags, TH_FL_STUCK);
 			goto update_and_leave;
 		}
@@ -92,13 +92,13 @@
 		 * CPU usage due to a configuration issue (like running tens
 		 * of thousands of tasks in a single loop), we'll check if the
-		 * scheduler is still alive by setting the TI_FL_STUCK flag
+		 * scheduler is still alive by setting the TH_FL_STUCK flag
 		 * that the scheduler clears when switching to the next task.
 		 * If it's already set, then it's our second call with no